Aydin Denoising of Chicken Embryos LSM 780 Images from the Pourquie lab (Harvard, Boston)
================================================================================================================


.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vRwKoAMXwjKd3M8UaLxnpKVcfm0UR7qVd_ur88FRaTOaWAw-7_7aAPeglnyH4FkI22nIj_408W-daIQ/pub?embedded=true" height="3180" width="720"></iframe>

